"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CexRepository = void 0;
const endpoints_1 = require("../core/endpoints");
const repository_1 = require("../core/repository");
const date_util_1 = require("../utils/date.util");
const type_util_1 = require("../utils/type.util");
class CexRepository extends repository_1.Repository {
    constructor() {
        super(...arguments);
        this.endpoints = endpoints_1.default.cex;
    }
    async list(status = "active", filter, limit, offset = 1, sort = "id", aux = ["first_historical_data", "last_historical_data", "is_active"]) {
        return await this.cmc.client.req(this.endpoints.map, Object.assign(Object.assign(Object.assign({}, ((filter === null || filter === void 0 ? void 0 : filter.cexSlug) && { slug: filter.cexSlug })), ((filter === null || filter === void 0 ? void 0 : filter.cryptoId) && { crypto_id: filter.cryptoId })), { listing_status: status, start: offset, limit: limit, sort: sort, aux: aux }));
    }
    async metadata(id, aux = ["urls", "logo", "description", "date_launched", "notice"]) {
        return await this.cmc.client.req(this.endpoints.metadata, Object.assign(Object.assign(Object.assign({}, ((id === null || id === void 0 ? void 0 : id.id) && { id: id.id })), ((id === null || id === void 0 ? void 0 : id.slug) && { slug: id.slug })), { aux: aux }));
    }
    async assets(id) {
        return await this.cmc.client.req(this.endpoints.assets, {
            id: id,
        });
    }
    async listing(limit = 100, offset = 1, category = "all", marketType = "all", sort = "volume_24h", sortDir, convert, aux = [
        "num_market_pairs",
        "traffic_score",
        "rank",
        "exchange_score",
        "effective_liquidity_24h",
    ]) {
        return await this.cmc.client.req(this.endpoints.listings, Object.assign({ limit: limit, start: offset, market_type: marketType, sort: sort, sort_dir: sortDir, category: category, aux: aux }, ((0, type_util_1.isNumeric)(convert) ? { convert_id: convert } : { convert })));
    }
    async marketPairs(id, limit = 100, offset = 1, matched, category = "all", feeType = "all", convert, aux = ["num_market_pairs", "category", "fee_type"]) {
        return await this.cmc.client.req(this.endpoints.pairs, Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, ((id === null || id === void 0 ? void 0 : id.id) && { id: id.id })), ((id === null || id === void 0 ? void 0 : id.slug) && { slug: id.slug })), ((matched === null || matched === void 0 ? void 0 : matched.id) && { matched_id: matched.id })), ((matched === null || matched === void 0 ? void 0 : matched.symbol) && { matched_symbol: matched.symbol })), ((0, type_util_1.isNumeric)(convert) ? { convert_id: convert } : { convert })), { limit: limit, start: offset, category: category, fee_type: feeType, aux: aux }));
    }
    async quotes(id, convert, aux = [
        "num_market_pairs",
        "traffic_score",
        "rank",
        "exchange_score",
        "liquidity_score",
        "effective_liquidity_24h",
    ]) {
        return await this.cmc.client.req(this.endpoints.quotes, Object.assign(Object.assign(Object.assign(Object.assign({}, ((id === null || id === void 0 ? void 0 : id.id) && { id: id.id })), ((id === null || id === void 0 ? void 0 : id.slug) && { slug: id.slug })), ((0, type_util_1.isNumeric)(convert) ? { convert_id: convert } : { convert })), { aux: aux }));
    }
    async quotesHistory(id, timeStart, timeEnd, count = 10, interval = "5m", convert) {
        return await this.cmc.client.req(this.endpoints.quotesHistorical, Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, ((id === null || id === void 0 ? void 0 : id.id) && { id: id.id })), ((id === null || id === void 0 ? void 0 : id.slug) && { slug: id.slug })), (timeStart && { time_start: (0, date_util_1.dateToUnix)(timeStart) })), (timeEnd && { time_end: (0, date_util_1.dateToUnix)(timeEnd) })), ((0, type_util_1.isNumeric)(convert) ? { convert_id: convert } : { convert })), { count: count, interval: interval }));
    }
}
exports.CexRepository = CexRepository;
//# sourceMappingURL=cex.repository.js.map