import type { Pair, Timestamp } from "../types/common.type";
import type { Quote, QuoteMap } from "./common.response";
export interface CexUrls {
    website: string[];
    blog: string[];
    chat: string[];
    fee: string[];
    twitter: string[];
}
export interface CexIdMap {
    id: number;
    name: string;
    slug: string;
    is_active: number;
    status?: "active" | "inactive" | "untracked";
    first_historical_data: Timestamp | null;
    last_historical_data: Timestamp | null;
}
export type CexIdMapResponse<TKey extends string = string> = Pair<TKey, CexIdMap>;
export type CexIdMapResponses = CexIdMap[];
export type CexMarketQuote = Pick<Quote, "volume_24h" | "volume_7d" | "volume_30d"> & {
    volume_24h_adjusted: number;
    percent_change_volume_24h: number;
    percent_change_volume_7d: number;
    percent_change_volume_30d: number;
    effective_liquidity_24h: number;
    derivative_volume?: number;
    open_interest?: number;
    derivative_volume_usd?: number;
    spot_volume_usd?: number;
};
export interface CexMetadata {
    id: number;
    name: string;
    slug: string;
    logo: string;
    description: string | null;
    date_launched: Timestamp;
    notice: string | null;
    countries: string[];
    fiats: string[];
    tags: string[] | null;
    type: string | null;
    maker_fee: number;
    taker_fee: number;
    weekly_visits: number;
    spot_volume_usd: number;
    spot_volume_last_updated?: Timestamp;
    urls: CexUrls;
}
export type CexMetadataResponse<TKey extends string = string> = Pair<TKey, CexMetadata>;
export interface CexAssetPlatform {
    crypto_id: number;
    symbol: string;
    name: string;
}
export interface CexAssetCurrency {
    crypto_id: number;
    symbol: string;
    name: string;
    price_usd: number;
}
export interface CexAsset {
    wallet_address: string;
    balance: number;
    platform: CexAssetPlatform;
    currency: CexAssetCurrency;
}
export type CexAssetsResponse<TKey extends string = string> = Pair<TKey, CexAsset[]> & CexAsset[];
export interface CexListing<TQuoteKey extends string = "USD", TQuoteValue extends object = CexMarketQuote> {
    id: number;
    name: string;
    slug: string;
    num_market_pairs: number;
    fiats?: string[];
    traffic_score: number;
    rank: number;
    exchange_score: null;
    liquidity_score: number | null;
    last_updated: Timestamp;
    quote: QuoteMap<TQuoteKey, TQuoteValue>;
}
export type CexListingLatestResponse<TQuoteKey extends string = "USD", TQuoteValue extends object = CexMarketQuote> = CexListing<TQuoteKey, TQuoteValue>[];
export interface CexMarketPairBase {
    currency_id: number;
    currency_name?: string;
    currency_symbol: string;
    exchange_symbol: string;
    currency_slug?: string;
    currency_type: "cryptocurrency" | "fiat";
}
export interface CexMarketPairQuoteExchangeReported {
    price: number;
    volume_24h_base: number;
    volume_24h_quote: number;
    volume_percentage: number;
    last_updated: Timestamp;
}
export interface CexMarketPairQuote {
    price: number;
    price_quote?: number;
    volume_24h: number;
    depth_negative_two: number;
    depth_positive_two: number;
    effective_liquidity?: number;
    market_score?: number;
    market_reputation?: number;
    last_updated: Timestamp;
}
export interface CexMarketPair<TQuoteKey extends string = "USD", TQuoteValue extends object = CexMarketPairQuote, TQuoteExchangeReported extends object = CexMarketPairQuoteExchangeReported> {
    market_id: number;
    market_pair: string;
    category: "spot" | "derivatives" | "otc";
    fee_type: "percentage" | "no-fees" | "transactional-mining" | "unknown";
    outlier_detected?: number | null;
    exclusions?: string | null;
    market_pair_base: CexMarketPairBase;
    market_pair_quote: CexMarketPairBase;
    quote: Pair<TQuoteKey, TQuoteValue> & {
        exchange_reported: TQuoteExchangeReported;
    };
}
export interface CexMarketPairs<TQuoteKey extends string = "USD", TQuoteValue extends object = CexMarketPairQuote> {
    id: number;
    name: string;
    slug: string;
    num_market_pairs: number;
    volume_24h: number;
    market_pairs: CexMarketPair<TQuoteKey, TQuoteValue>[];
}
export type CexMarketPairsResponse<TKey extends string = string, TQuoteKey extends string = "USD", TQuoteValue extends object = CexMarketPairQuote> = Pair<TKey, CexMarketPairs<TQuoteKey, TQuoteValue>>;
export interface CexQuotesValue {
    volume_24h: number;
    volume_24h_adjusted: number;
    volume_7d: number;
    volume_30d: number;
    percent_change_volume_24h: number;
    percent_change_volume_7d: number;
    percent_change_volume_30d: number;
    effective_liquidity_24h: number;
    derivative_volume: number;
    spot_volume: number;
    last_updated: Timestamp;
}
export interface CexQuotes<TQuoteKey extends string = "USD", TQuoteValue extends object = CexQuotesValue> {
    id: number;
    name: string;
    slug: string;
    num_market_pairs: number;
    exchange_score: null;
    liquidity_score: number;
    rank: number;
    traffic_score: number;
    last_updated: Timestamp;
    quote: QuoteMap<TQuoteKey, TQuoteValue>;
}
export type CexQuotesLatestResponse<TKey extends string = string, TQuoteKey extends string = "USD", TQuoteValue extends object = CexQuotesValue> = Pair<TKey, CexQuotes<TQuoteKey, TQuoteValue>>;
export interface CexQuotesHistoricalQuote {
    volume_24h: number;
    timestamp: Timestamp;
}
export interface CexQuotesHistoricalQuotes<TQuoteKey extends string = "USD", TQuoteValue extends object = CexQuotesHistoricalQuote> {
    num_market_pairs: number;
    timestamp: Timestamp;
    quote: QuoteMap<TQuoteKey, TQuoteValue>;
}
export interface CexQuotesHistorical<TQuoteKey extends string = "USD", TQuoteValue extends object = CexQuotesHistoricalQuote> {
    id: number;
    name: string;
    slug: string;
    quotes: CexQuotesHistoricalQuotes<TQuoteKey, TQuoteValue>[];
}
export type CexQuotesHistoricalResponse<TKey extends string = string, TQuoteKey extends string = "USD", TQuoteValue extends object = CexQuotesHistoricalQuote> = Pair<TKey, CexQuotesHistorical<TQuoteKey, TQuoteValue>>;
